@@ -2,15 +2,15 @@
 
 #include "kiwixapp.h"
 #include "static_content.h"
-#include <kiwix/tools/networkTools.h>
-#include <kiwix/tools/otherTools.h>
 #include <kiwix/manager.h>
+#include <kiwix/tools.h>
 
 #include <QDebug>
 #include <QUrlQuery>
 #include <QUrl>
 #include <QDir>
 #include <QStorageInfo>
+#include <QMessageBox>
 
 ContentManager::ContentManager(Library* library, kiwix::Downloader* downloader, QObject *parent)
     : QObject(parent),
@@ -51,7 +51,7 @@ QStringList ContentManager::getTranslations(const QStringList &keys)
 QStringList ContentManager::getBookInfos(QString id, const QStringList &keys)
 {
     QStringList values;
-    kiwix::Book* b = [=]()->kiwix::Book* {
+    const kiwix::Book* b = [=]()->const kiwix::Book* {
         try {
             return &mp_library->getBookById(id);
         } catch (...) {
@@ -121,7 +121,20 @@ QStringList ContentManager::getBookInfos(QString id, const QStringList &keys)
 void ContentManager::openBook(const QString &id)
 {
     QUrl url("zim://"+id+".zim/");
-    KiwixApp::instance()->openUrl(url, true);
+    try {
+        KiwixApp::instance()->openUrl(url, true);
+    } catch (const std::exception& e) {
+        auto tabBar = KiwixApp::instance()->getTabWidget();
+        tabBar->closeTab(1);
+        auto text = gt("zim-open-fail-text");
+        text = text.replace("{{ZIM}}", QString::fromStdString(mp_library->getBookById(id).getPath()));
+        auto title = gt("zim-open-fail-title");
+        KiwixApp::instance()->showMessage(text, title, QMessageBox::Warning);
+        mp_library->removeBookFromLibraryById(id);
+        tabBar->setCurrentIndex(0);
+        emit(booksChanged());
+        return;
+    }
 }
 
 #define ADD_V(KEY, METH) {if(key==KEY) {values.append(QString::fromStdString((d->METH()))); continue;}}
@@ -138,7 +151,9 @@ QStringList ContentManager::updateDownloadInfos(QString id, const QStringList &k
     try {
         d = mp_downloader->getDownload(b.getDownloadId());
     } catch(...) {
-        b.setDownloadId("");
+        kiwix::Book bCopy(b);
+        bCopy.setDownloadId("");
+        mp_library->getKiwixLibrary().addOrUpdateBook(bCopy);
         mp_library->save();
         emit(mp_library->booksChanged());
         return values;
@@ -147,9 +162,13 @@ QStringList ContentManager::updateDownloadInfos(QString id, const QStringList &k
     d->updateStatus(true);
     if (d->getStatus() == kiwix::Download::K_COMPLETE) {
         QString tmp(QString::fromStdString(d->getPath()));
-        b.setPath(QDir::toNativeSeparators(tmp).toStdString());
-        b.setDownloadId("");
-        b.setPathValid(true);
+        kiwix::Book bCopy(b);
+        bCopy.setPath(QDir::toNativeSeparators(tmp).toStdString());
+        bCopy.setDownloadId("");
+        bCopy.setPathValid(true);
+        // removing book url so that download link in kiwix-serve is not displayed.
+        bCopy.setUrl("");
+        mp_library->getKiwixLibrary().addOrUpdateBook(bCopy);
         mp_library->save();
         mp_library->bookmarksChanged();
         if (!m_local) {
@@ -208,7 +227,7 @@ QString ContentManager::downloadBook(const QString &id)
 {
     if (!mp_downloader)
         return "";
-    auto& book = [&]()->kiwix::Book& {
+    const auto& book = [&]()->const kiwix::Book& {
         try {
             return m_remoteLibrary.getBookById(id.toStdString());
         } catch (...) {
@@ -232,8 +251,9 @@ QString ContentManager::downloadBook(const QString &id)
     } catch (std::exception& e) {
         return "";
     }
-    book.setDownloadId(download->getDid());
-    mp_library->addBookToLibrary(book);
+    kiwix::Book bookCopy(book);
+    bookCopy.setDownloadId(download->getDid());
+    mp_library->addBookToLibrary(bookCopy);
     mp_library->save();
     emit(oneBookChanged(id));
     return QString::fromStdString(download->getDid());
@@ -250,18 +270,10 @@ void ContentManager::eraseBookFilesFromComputer(const QString dirPath, const QSt
 void ContentManager::eraseBook(const QString& id)
 {
     auto tabBar = KiwixApp::instance()->getTabWidget();
-    int i = 1;
-    while (i < tabBar->count() - 1) {
-        WebView* webView = tabBar->widget(i)->getWebView();
-        if (webView->zimId() == id) {
-            tabBar->closeTab(i);
-        } else {
-            i++;
-        }
-    }
+    tabBar->closeTabsByZimId(id);
     kiwix::Book book = mp_library->getBookById(id);
-    QString dirPath = QString::fromStdString(removeLastPathElement(book.getPath()));
-    QString filename = QString::fromStdString(getLastPathElement(book.getPath())) + "*";
+    QString dirPath = QString::fromStdString(kiwix::removeLastPathElement(book.getPath()));
+    QString filename = QString::fromStdString(kiwix::getLastPathElement(book.getPath())) + "*";
     eraseBookFilesFromComputer(dirPath, filename);
     mp_library->removeBookFromLibraryById(id);
     mp_library->save();
@@ -306,8 +318,8 @@ void ContentManager::cancelBook(const QString& id)
     if (download->getStatus() != kiwix::Download::K_COMPLETE) {
         download->cancelDownload();
     }
-    QString dirPath = QString::fromStdString(removeLastPathElement(download->getPath()));
-    QString filename = QString::fromStdString(getLastPathElement(download->getPath())) + "*";
+    QString dirPath = QString::fromStdString(kiwix::removeLastPathElement(download->getPath()));
+    QString filename = QString::fromStdString(kiwix::getLastPathElement(download->getPath())) + "*";
     eraseBookFilesFromComputer(dirPath, filename);
     mp_library->removeBookFromLibraryById(id);
     mp_library->save();
@@ -406,6 +418,8 @@ QStringList ContentManager::getBookIds()
 
     filter.acceptTags(tags);
     filter.query(m_searchQuery.toStdString());
+    if (m_currentLanguage != "*")
+        filter.lang(m_currentLanguage.toStdString());
 
     if (m_local) {
         filter.local(true);
