@@ -6,7 +6,6 @@
 #include "mainwindow.h"
 #include "kiwix/downloader.h"
 #include <kiwix/kiwixserve.h>
-#include "tabbar.h"
 #include "kprofile.h"
 #include "urlschemehandler.h"
 #include "settingsmanager.h"
@@ -15,13 +14,16 @@
 #include <QtSingleApplication>
 #include <QApplication>
 #include <QErrorMessage>
+#include <QMessageBox>
 #include <QTranslator>
+#include <kiwix/name_mapper.h>
+
+#include <mutex>
 
 
 class KiwixApp : public QtSingleApplication
 {
     Q_OBJECT
-    Q_PROPERTY(SideBarType currentSideType MEMBER m_currentSideType NOTIFY currentSideTypeChanged)
 
 public:
     enum Actions {
@@ -45,6 +47,8 @@ public:
         ZoomInAction,
         ZoomOutAction,
         ZoomResetAction,
+        HistoryBackAction,
+        HistoryForwardAction,
         HelpAction,
         FeedbackAction,
         ReportBugAction,
@@ -55,11 +59,6 @@ public:
         ExitAction,
         MAX_ACTION
     };
-    enum SideBarType {
-        CONTENTMANAGER_BAR,
-        READINGLIST_BAR,
-        NONE
-    };
 
     KiwixApp(int& argc, char *argv[]);
     virtual ~KiwixApp();
@@ -68,34 +67,33 @@ public:
 
     void openRandomUrl(bool newTab=true);
 
-    void showMessage(const QString& message);
+    void showMessage(const QString& message, const QString& title, const enum QMessageBox::Icon& icon);
 
     KProfile* getProfile() { return &m_profile; }
     Library* getLibrary() { return &m_library; }
     MainWindow* getMainWindow() { return mp_mainWindow; }
+    ContentManager* getContentManager() { return mp_manager; }
     kiwix::Downloader* getDownloader() { return mp_downloader; }
     TabBar* getTabWidget() { return mp_tabWidget; }
     QAction* getAction(Actions action);
     QString getLibraryDirectory() { return m_libraryDirectory; };
     kiwix::Server* getLocalServer() { return &m_server; }
     SettingsManager* getSettingsManager() { return &m_settingsManager; };
-    SideBarType getSideType() { return m_currentSideType; }
     QString getText(const QString &key) { return m_translation.getText(key); };
 
     bool isCurrentArticleBookmarked();
 
 signals:
     void currentTitleChanged(const QString& title);
-    void currentSideTypeChanged(SideBarType type);
 
 public slots:
     void openZimFile(const QString& zimfile="");
     void openUrl(const QString& url, bool newTab=true);
     void openUrl(const QUrl& url, bool newTab=true);
-    void setSideBar(SideBarType type);
-    void toggleSideBar(KiwixApp::SideBarType type);
     void printPage();
     void disableItemsOnLibraryPage(bool displayed);
+    void updateNameMapper();
+    void printVersions(std::ostream& out = std::cout);
 
 protected:
     void createAction();
@@ -111,8 +109,8 @@ private:
     ContentManager* mp_manager;
     MainWindow* mp_mainWindow;
     TabBar* mp_tabWidget;
-    SideBarType m_currentSideType;
     QErrorMessage* mp_errorDialog;
+    kiwix::UpdatableNameMapper m_nameMapper;
     kiwix::Server m_server;
     Translation m_translation;
 
@@ -122,5 +120,7 @@ private:
 };
 
 QString gt(const QString &key);
-
+#define _STR(...) # __VA_ARGS__
+#define STR(X) _STR(X)
+static QString version = STR(VERSION);
 #endif // KIWIXAPP_H
