@@ -2,14 +2,16 @@
 #include "kiwixapp.h"
 
 #include <kiwix/manager.h>
-#include "kiwixapp.h"
+#include <kiwix/tools.h>
 
 #include <QtDebug>
 
 class LibraryManipulator: public kiwix::LibraryManipulator {
   public:
     LibraryManipulator(Library* p_library)
-        : mp_library(p_library) {}
+        : kiwix::LibraryManipulator(&p_library->getKiwixLibrary())
+        , mp_library(p_library)
+    {}
     virtual ~LibraryManipulator() {}
     bool addBookToLibrary(kiwix::Book book) {
         auto ret = mp_library->m_library.addBook(book);
@@ -27,8 +29,8 @@ Library::Library(const QString& libraryDirectory)
 {
     auto manipulator = LibraryManipulator(this);
     auto manager = kiwix::Manager(&manipulator);
-    manager.readFile(appendToDirectory(m_libraryDirectory.toStdString(),"library.xml"), false);
-    manager.readBookmarkFile(appendToDirectory(m_libraryDirectory.toStdString(),"library.bookmarks.xml"));
+    manager.readFile(kiwix::appendToDirectory(m_libraryDirectory.toStdString(),"library.xml"), false);
+    manager.readBookmarkFile(kiwix::appendToDirectory(m_libraryDirectory.toStdString(),"library.bookmarks.xml"));
     emit(booksChanged());
 }
 
@@ -46,6 +48,9 @@ QString Library::openBookFromPath(const QString &zimPath)
 
     kiwix::Manager manager(&m_library);
     auto id =  manager.addBookFromPathAndGetId(zimPath.toStdString());
+    if (id == "") {
+        throw std::invalid_argument("invalid zim file");
+    }
     save();
     emit(booksChanged());
     return QString::fromStdString(id);
@@ -114,11 +119,11 @@ void Library::removeBookmark(const QString &zimId, const QString &url)
 
 void Library::save()
 {
-    m_library.writeToFile(appendToDirectory(m_libraryDirectory.toStdString(),"library.xml"));
-    m_library.writeBookmarksToFile(appendToDirectory(m_libraryDirectory.toStdString(), "library.bookmarks.xml"));
+    m_library.writeToFile(kiwix::appendToDirectory(m_libraryDirectory.toStdString(),"library.xml"));
+    m_library.writeBookmarksToFile(kiwix::appendToDirectory(m_libraryDirectory.toStdString(), "library.bookmarks.xml"));
 }
 
-kiwix::Book &Library::getBookById(QString id)
+const kiwix::Book &Library::getBookById(QString id) const
 {
     return m_library.getBookById(id.toStdString());
 }
