@@ -7,7 +7,6 @@
 #if QT_VERSION >= QT_VERSION_CHECK(5, 12, 0)
   #include <QWebEngineUrlScheme>
 #endif
-
 int main(int argc, char *argv[])
 {
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
@@ -16,21 +15,28 @@ int main(int argc, char *argv[])
     QWebEngineUrlScheme::registerScheme(scheme);
 #endif
     KiwixApp a(argc, argv);
-    QCommandLineParser parser;
-    QString zimfile;
 
+    QCommandLineParser parser;
+    parser.setApplicationDescription(QStringLiteral("The Kiwix Desktop is a viewer/manager of ZIM files for GNU/Linux and Microsoft Windows OSes."));
+    parser.addHelpOption();
     parser.addPositionalArgument("zimfile", "The zim file");
+
+    // Set version string
+    std::ostringstream versions;
+    a.printVersions(versions);
+    a.setApplicationVersion(QString::fromStdString(versions.str()));
+    parser.addVersionOption();
+
     parser.process(a);
     auto positionalArguments = parser.positionalArguments();
-    if (positionalArguments.size() >= 1) {
-        zimfile = parser.positionalArguments().at(0);
-    }
     if (a.isRunning()) {
-        a.sendMessage(zimfile);
+        for (QString zimfile : positionalArguments) {
+            a.sendMessage(zimfile);
+        }
         return 0;
     }
     a.init();
-    if (!zimfile.isEmpty()) {
+    for (QString zimfile : positionalArguments) {
         a.openZimFile(zimfile);
     }
     return a.exec();
