@@ -2,10 +2,10 @@
 #define ZIMVIEW_H
 
 #include <QWidget>
-#include "webview.h"
 #include "findinpagebar.h"
 
 class TabBar;
+class WebView;
 
 class ZimView : public QWidget
 {
@@ -17,13 +17,10 @@ public:
     FindInPageBar *getFindInPageBar() { return mp_findInPageBar; }
     void openFindInPageBar();
 
-signals:
-
 private:
     WebView *mp_webView;
     TabBar *mp_tabBar;
     FindInPageBar *mp_findInPageBar;
-
 };
 
 #endif // ZIMVIEW_H
